"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var path_1 = __importDefault(require("path"));
var yargs_1 = require("yargs");
var fs_1 = require("../../../shared/fs");
var webpack_1 = require("../cosmosConfig/webpack");
var default_1 = require("./default");
var module_1 = require("./module");
function getBaseWebpackConfig(cosmosConfig, userWebpack) {
    var rootDir = cosmosConfig.rootDir;
    var configPath = webpack_1.createWebpackCosmosConfig(cosmosConfig).configPath;
    if (!configPath || !fs_1.moduleExists(configPath)) {
        console.log('[Cosmos] Using default webpack config');
        return default_1.getDefaultWebpackConfig(userWebpack, rootDir);
    }
    var relPath = path_1.default.relative(process.cwd(), configPath);
    console.log("[Cosmos] Using webpack config found at " + relPath);
    var userConfig = module_1.getDefaultExport(fs_1.requireModule(configPath));
    return typeof userConfig === 'function'
        ? userConfig(process.env.NODE_ENV, yargs_1.argv)
        : userConfig;
}
exports.getBaseWebpackConfig = getBaseWebpackConfig;
function resolveDomRendererPath(relPath) {
    return require.resolve("../../../domRenderer/" + relPath);
}
exports.resolveDomRendererPath = resolveDomRendererPath;
function resolveClientPath(relPath) {
    return require.resolve("../client/" + relPath);
}
exports.resolveClientPath = resolveClientPath;
function getUserDepsLoaderRule() {
    return {
        loader: require.resolve('./userDepsLoader'),
        include: resolveClientPath('userDeps')
    };
}
exports.getUserDepsLoaderRule = getUserDepsLoaderRule;
function getEnvVarPlugin(_a, userWebpack, isDev) {
    var publicUrl = _a.publicUrl;
    var cleanPublicUrl = removeTrailingSlash(publicUrl);
    return new userWebpack.DefinePlugin({
        // Having __DEV__ as boolean is useful because "if (__DEV__)" blocks can
        // get stripped automatically when compiling a static export build
        __DEV__: JSON.stringify(isDev),
        'process.env': {
            NODE_ENV: JSON.stringify(isDev ? 'development' : 'production'),
            PUBLIC_URL: JSON.stringify(cleanPublicUrl)
        }
    });
}
exports.getEnvVarPlugin = getEnvVarPlugin;
function hasPlugin(plugins, pluginName) {
    return (plugins && plugins.filter(function (p) { return isInstanceOfPlugin(p, pluginName); }).length > 0);
}
exports.hasPlugin = hasPlugin;
function isInstanceOfPlugin(plugin, constructorName) {
    return plugin.constructor && plugin.constructor.name === constructorName;
}
exports.isInstanceOfPlugin = isInstanceOfPlugin;
function removeTrailingSlash(url) {
    return url.replace(/\/$/, '');
}
